@@ -22,6 +22,7 @@
 """Formats Python code to follow a consistent style."""
 
 from __future__ import print_function
+from __future__ import unicode_literals
 
 import io
 import sys
@@ -32,7 +33,7 @@ import docformatter
 import unify
 
 
-__version__ = '0.2.4'
+__version__ = '0.3'
 
 
 try:
@@ -44,19 +45,15 @@ except NameError:
 def formatters(aggressive):
     """Return list of code formatters."""
     if aggressive:
+        yield autoflake.fix_code
+
         autopep8_options = autopep8.parse_args(['', '--aggressive'])[0]
     else:
         autopep8_options = None
 
-    return [
-        autoflake.fix_code,
-        lambda code: autopep8.fix_string(
-            code,
-            options=autopep8_options),
-        lambda code: docformatter.format_code(code,
-                                              summary_wrap_length=79),
-        unify.format_code
-    ]
+    yield lambda code: autopep8.fix_string(code, options=autopep8_options)
+    yield lambda code: docformatter.format_code(code, summary_wrap_length=79)
+    yield unify.format_code
 
 
 def format_code(source, aggressive=False):
@@ -91,7 +88,7 @@ def format_file(filename, args, standard_out):
                 io.StringIO(source).readlines(),
                 io.StringIO(formatted_source).readlines(),
                 filename)
-            standard_out.write(unicode().join(diff))
+            standard_out.write(''.join(diff))
 
 
 def _format_file(parameters):
@@ -101,7 +98,7 @@ def _format_file(parameters):
     standard_error = standard_error or sys.stderr
 
     if args.verbose:
-        print(unicode('[file:{0}]'.format(filename)),
+        print('[file:{0}]'.format(filename),
               file=standard_error)
     try:
         format_file(*parameters[:-1])
@@ -175,7 +172,7 @@ def main(argv, standard_out, standard_error):
     args = parse_args(argv)
 
     if args.jobs > 1 and not args.in_place:
-        print(unicode('parallel jobs requires --in-place'),
+        print('parallel jobs requires --in-place',
               file=standard_error)
         return 1
 
