@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 """Test that pyformat runs without crashing on various Python files."""
 
+from __future__ import unicode_literals
+
 import os
 import sys
 import subprocess
@@ -18,11 +20,6 @@ else:
     YELLOW = ''
     END = ''
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 
 def colored(text, color):
     """Return color coded text."""
@@ -40,7 +37,7 @@ def readlines(filename):
 def diff(before, after):
     """Return diff of two files."""
     import difflib
-    return unicode().join(difflib.unified_diff(
+    return ''.join(difflib.unified_diff(
         readlines(before),
         readlines(after),
         before,
@@ -114,7 +111,7 @@ def process_args():
         default=-1,
         type=float)
 
-    parser.add_argument('--aggressive',
+    parser.add_argument('--aggressive', action='store_true',
                         help='pass to the pyformat "--aggressive" option')
 
     parser.add_argument('-v', '--verbose', action='store_true',
